| Title: | Locate Trans and Intersex-Friendly Toilets |
|---|---|
| Description: | Access the 'Refuge' API, a web-application for locating trans and intersex-friendly restrooms, including unisex and accessible restrooms. Includes data on the location of restrooms, along with directions, comments, user ratings and amenities. Coverage is global, but data is most comprehensive in the United States. See <https://www.refugerestrooms.org/api/docs/> for full API documentation. |
| Authors: | Evan Odell [aut, cre] (ORCID: <https://orcid.org/0000-0003-1845-808X>) |
| Maintainer: | Evan Odell <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.3 |
| Built: | 2026-05-28 10:17:08 UTC |
| Source: | https://github.com/evanodell/refuge |
All listed refuge restrooms, ordered by date added or last updated, with the most recent additions and updates at the top.
rfg_all_restrooms( accessible = FALSE, unisex = FALSE, verbose = TRUE, tidy = FALSE )rfg_all_restrooms( accessible = FALSE, unisex = FALSE, verbose = TRUE, tidy = FALSE )
accessible |
If |
unisex |
If |
verbose |
If |
tidy |
If |
Note that the API does not standardise or validate the names of states, cities, countries, etc, and so this data may need to be cleaned and organised.
A tibble with details on all listed bathrooms.
## Not run: a <- rfg_all_restrooms(accessible = TRUE, unisex = TRUE) ## End(Not run)## Not run: a <- rfg_all_restrooms(accessible = TRUE, unisex = TRUE) ## End(Not run)
Requests all records on bathrooms created or updated on or after a given date.
rfg_date( date = NULL, accessible = FALSE, unisex = FALSE, updated = FALSE, verbose = TRUE, tidy = FALSE )rfg_date( date = NULL, accessible = FALSE, unisex = FALSE, updated = FALSE, verbose = TRUE, tidy = FALSE )
date |
A date in "yyyy-mm-dd" format, or any format that can be
coerced to a date with |
accessible |
If |
unisex |
If |
updated |
If |
verbose |
If |
tidy |
If |
A tibble with all bathrooms recorded or updated on or after the given date.
## Not run: q <- rfg_date("2017-11-04") ## End(Not run)## Not run: q <- rfg_date("2017-11-04") ## End(Not run)
Given a pair of coordinates (latitude and longitude), finds any nearby bathrooms, subject to other parameters.
rfg_location( lat, lng, accessible = FALSE, unisex = FALSE, verbose = TRUE, tidy = FALSE )rfg_location( lat, lng, accessible = FALSE, unisex = FALSE, verbose = TRUE, tidy = FALSE )
lat |
Location latitude |
lng |
Location longitude |
accessible |
If |
unisex |
If |
verbose |
If |
tidy |
If |
A tibble with details of any and all nearby refuge bathrooms.
## Not run: c <- rfg_location(lat = 39, lng = -75) ## End(Not run)## Not run: c <- rfg_location(lat = 39, lng = -75) ## End(Not run)
Restroom record search
rfg_search( search, accessible = FALSE, unisex = FALSE, verbose = TRUE, tidy = FALSE )rfg_search( search, accessible = FALSE, unisex = FALSE, verbose = TRUE, tidy = FALSE )
search |
A string to search for. Note that the API does not accept wildcard searchs, searches all fields in all available records, and only returns exact (case-insensitive) whole-word matches. |
accessible |
If |
unisex |
If |
verbose |
If |
tidy |
If |
A tibble with all bathrooms matching your search request
## Not run: s <- rfg_search(search = "toronto") ## End(Not run)## Not run: s <- rfg_search(search = "toronto") ## End(Not run)